@@ -1,4 +1,4 @@
-package iot
+package iot_test
 
 import (
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
